@@ -7,13 +7,14 @@ from plone.memoize.view import memoize
 from plone.protect.authenticator import createToken
 from Products.CMFCore.interfaces import IIndexQueueProcessor
 from Products.Five import BrowserView
+from pysolr import SolrError
 from rer.solrpush import _
 from rer.solrpush.utils import push_to_solr
 from rer.solrpush.utils import remove_from_solr
 from rer.solrpush.utils import reset_solr
 from rer.solrpush.utils import search
-from rer.solrpush.utils.solr_indexer import can_index
 from rer.solrpush.utils.solr_common import is_solr_active
+from rer.solrpush.utils.solr_indexer import can_index
 from rer.solrpush.utils.solr_indexer import get_site_title
 from rer.solrpush.utils.solr_indexer import parse_date_as_datetime
 from time import strftime
@@ -25,6 +26,7 @@ from zope.annotation.interfaces import IAnnotations
 from zope.component import getMultiAdapter
 from zope.component import getSiteManager
 from zope.i18n import translate
+
 import json
 import logging
 import os
@@ -279,7 +281,7 @@ class ReindexBaseView(BrowserView):
                     len(results["indexed"])
                 )
             )
-            for path in results["synced"]:
+            for path in results["indexed"]:
                 logger.info("- {}".format(path))
         if len(results["removed"]):
             logger.info(
@@ -290,9 +292,18 @@ class ReindexBaseView(BrowserView):
             for path in results["removed"]:
                 logger.info("- {}".format(path))
         if len(results["not_indexed"]):
-            logger.warning("NOT indexed {} items (errors):")
-            for path in results["not_indexed"]:
-                logger.info("- {}".format(path))
+            logger.info(
+                "NOT indexed {} items (errors):".format(
+                    len(results["not_indexed"])
+                )
+            )
+            for error in results["not_indexed"]:
+                logger.info(
+                    "- {path} ({message})".format(
+                        path=error.get("path", ""),
+                        message=error.get("message", "Undefined Error"),
+                    )
+                )
 
     def sync_contents(
         self, brains_to_sync, solr_items, disable_progress=False
@@ -308,15 +319,21 @@ class ReindexBaseView(BrowserView):
             if not disable_progress:
                 status["counter"] = status["counter"] + 1
                 commit()
+            item = brain.getObject()
             if brain.UID not in solr_items:
                 # missing from solr: try to index it
                 try:
-                    res = push_to_solr(brain.getObject())
+                    res = push_to_solr(item)
                     if res:
                         indexed.append(brain.getPath())
+                except SolrError as e:
+                    not_indexed.append(
+                        {"path": brain.getPath(), "message": e.__str__()}
+                    )
                 except Exception as e:
-                    logger.exception(e)
-                    not_indexed.append(brain.getPath())
+                    not_indexed.append(
+                        {"path": brain.getPath(), "message": e.message}
+                    )
             else:
                 item = brain.getObject()
                 if not can_index(item):
@@ -333,8 +350,9 @@ class ReindexBaseView(BrowserView):
                         if res:
                             indexed.append(brain.getPath())
                     except Exception as e:
-                        logger.exception(e)
-                        not_indexed.append(brain.getPath())
+                        not_indexed.append(
+                            {"path": brain.getPath(), "message": e.message}
+                        )
         if not disable_progress:
             status["in_progress"] = False
         return {
